@@ -196,16 +196,16 @@ meta= {
 |        |                   |        |          |                           |                 |        | s ommited in va |
 |        |                   |        |          |                           |                 |        | lue string.     |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
-| b      | ever (2019-02-19  |        | finetime | [(0, 9876543210123456): e | 1958-01-01      |        | date param      |
-|        | 01:02:03.456789   |        |          | ver]                      | 00:00:00.000099 |        |                 |
+| b      | xy (2019-02-19    |        | finetime | (0, 9876543210123456): xy | 1958-01-01      |        | date param      |
+|        | 01:02:03.456789   |        |          |                           | 00:00:00.000099 |        |                 |
 |        | 1929229323456789) |        |          |                           | 99              |        |                 |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
-| c      | Invalid (Right)   |        | string   | '': empty                 | cliche          | B      | str parameter.  |
+| c      | Invalid (IJK)     |        | string   | '': empty                 | cliche          | B      | str parameter.  |
 |        |                   |        |          |                           |                 |        | but only "" is  |
 |        |                   |        |          |                           |                 |        | allowed.        |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
-| d      | off (0b00)        | None   | binary   | 0b110: 0b00               | 0b0             | None   | valid rules des |
-|        |                   |        |          |                           |                 |        | cribed with bin |
+| d      | off (0b00)        | None   | binary   | 11000 0b01: on            | 0b0             | None   | valid rules des |
+|        |                   |        |          | 11000 0b00: off           |                 |        | cribed with bin |
 |        |                   |        |          |                           |                 |        | ary masks       |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
 MetaData-listeners = ListnerSet{}}
@@ -215,12 +215,12 @@ level 1, repr
 # GenericDataset
 description= {'test GD'},
 meta= {
--------------  -------------------  ------------------
-a= 3.4         b= ever (2019-02-19  c= Invalid (Right)
+-------------  -----------------  ----------------
+a= 3.4         b= xy (2019-02-19  c= Invalid (IJK)
                01:02:03.456789
                1929229323456789)
 d= off (0b00)
--------------  -------------------  ------------------
+-------------  -----------------  ----------------
 MetaData-listeners = ListnerSet{}
 }
 GenericDataset-dataset =
@@ -240,16 +240,16 @@ meta= {
 |        |                   |        |          |                           |                 |        | s ommited in va |
 |        |                   |        |          |                           |                 |        | lue string.     |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
-| b      | ever (2019-02-19  |        | finetime | [(0, 9876543210123456): e | 1958-01-01      |        | date param      |
-|        | 01:02:03.456789   |        |          | ver]                      | 00:00:00.000099 |        |                 |
+| b      | xy (2019-02-19    |        | finetime | (0, 9876543210123456): xy | 1958-01-01      |        | date param      |
+|        | 01:02:03.456789   |        |          |                           | 00:00:00.000099 |        |                 |
 |        | 1929229323456789) |        |          |                           | 99              |        |                 |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
-| c      | Invalid (Right)   |        | string   | '': empty                 | cliche          | B      | str parameter.  |
+| c      | Invalid (IJK)     |        | string   | '': empty                 | cliche          | B      | str parameter.  |
 |        |                   |        |          |                           |                 |        | but only "" is  |
 |        |                   |        |          |                           |                 |        | allowed.        |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
-| d      | off (0b00)        | None   | binary   | 0b110: 0b00               | 0b0             | None   | valid rules des |
-|        |                   |        |          |                           |                 |        | cribed with bin |
+| d      | off (0b00)        | None   | binary   | 11000 0b01: on            | 0b0             | None   | valid rules des |
+|        |                   |        |          | 11000 0b00: off           |                 |        | cribed with bin |
 |        |                   |        |          |                           |                 |        | ary masks       |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
 MetaData-listeners = ListnerSet{}},
@@ -303,12 +303,12 @@ level 1, repr
 # ArrayDataset
 description= {'toString tester AD'},
 meta= {
--------------  -------------------  ------------------
-a= 3.4         b= ever (2019-02-19  c= Invalid (Right)
+-------------  -----------------  ----------------
+a= 3.4         b= xy (2019-02-19  c= Invalid (IJK)
                01:02:03.456789
                1929229323456789)
 d= off (0b00)
--------------  -------------------  ------------------
+-------------  -----------------  ----------------
 MetaData-listeners = ListnerSet{}
 },
 type= {None},
@@ -359,12 +359,12 @@ ArrayDataset-dataset =
 
 level 2,
 ArrayDataset{ [[[[0, 0, 0, ...0]]], [[[0, 0, 0, ...0]]]] (lyr) <None>, "toString tester AD", default None, tcode=None, meta=
--------------  -------------------  ------------------
-a= 3.4         b= ever (2019-02-19  c= Invalid (Right)
+-------------  -----------------  ----------------
+a= 3.4         b= xy (2019-02-19  c= Invalid (IJK)
                01:02:03.456789
                1929229323456789)
 d= off (0b00)
--------------  -------------------  ------------------
+-------------  -----------------  ----------------
 MetaData-listeners = ListnerSet{}}"""
 out_TableDataset = """level 0
 # TableDataset
@@ -379,16 +379,16 @@ meta= {
 |        |                   |        |          |                           |                 |        | s ommited in va |
 |        |                   |        |          |                           |                 |        | lue string.     |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
-| b      | ever (2019-02-19  |        | finetime | [(0, 9876543210123456): e | 1958-01-01      |        | date param      |
-|        | 01:02:03.456789   |        |          | ver]                      | 00:00:00.000099 |        |                 |
+| b      | xy (2019-02-19    |        | finetime | (0, 9876543210123456): xy | 1958-01-01      |        | date param      |
+|        | 01:02:03.456789   |        |          |                           | 00:00:00.000099 |        |                 |
 |        | 1929229323456789) |        |          |                           | 99              |        |                 |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
-| c      | Invalid (Right)   |        | string   | '': empty                 | cliche          | B      | str parameter.  |
+| c      | Invalid (IJK)     |        | string   | '': empty                 | cliche          | B      | str parameter.  |
 |        |                   |        |          |                           |                 |        | but only "" is  |
 |        |                   |        |          |                           |                 |        | allowed.        |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
-| d      | off (0b00)        | None   | binary   | 0b110: 0b00               | 0b0             | None   | valid rules des |
-|        |                   |        |          |                           |                 |        | cribed with bin |
+| d      | off (0b00)        | None   | binary   | 11000 0b01: on            | 0b0             | None   | valid rules des |
+|        |                   |        |          | 11000 0b00: off           |                 |        | cribed with bin |
 |        |                   |        |          |                           |                 |        | ary masks       |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
 MetaData-listeners = ListnerSet{}}
@@ -405,12 +405,12 @@ level 1, repr
 # TableDataset
 description= {'UNKNOWN'},
 meta= {
--------------  -------------------  ------------------
-a= 3.4         b= ever (2019-02-19  c= Invalid (Right)
+-------------  -----------------  ----------------
+a= 3.4         b= xy (2019-02-19  c= Invalid (IJK)
                01:02:03.456789
                1929229323456789)
 d= off (0b00)
--------------  -------------------  ------------------
+-------------  -----------------  ----------------
 MetaData-listeners = ListnerSet{}
 }
 TableDataset-dataset =
@@ -447,16 +447,16 @@ meta= {
 |        |                   |        |          |                           |                 |        | s ommited in va |
 |        |                   |        |          |                           |                 |        | lue string.     |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
-| b      | ever (2019-02-19  |        | finetime | [(0, 9876543210123456): e | 1958-01-01      |        | date param      |
-|        | 01:02:03.456789   |        |          | ver]                      | 00:00:00.000099 |        |                 |
+| b      | xy (2019-02-19    |        | finetime | (0, 9876543210123456): xy | 1958-01-01      |        | date param      |
+|        | 01:02:03.456789   |        |          |                           | 00:00:00.000099 |        |                 |
 |        | 1929229323456789) |        |          |                           | 99              |        |                 |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
-| c      | Invalid (Right)   |        | string   | '': empty                 | cliche          | B      | str parameter.  |
+| c      | Invalid (IJK)     |        | string   | '': empty                 | cliche          | B      | str parameter.  |
 |        |                   |        |          |                           |                 |        | but only "" is  |
 |        |                   |        |          |                           |                 |        | allowed.        |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
-| d      | off (0b00)        | None   | binary   | 0b110: 0b00               | 0b0             | None   | valid rules des |
-|        |                   |        |          |                           |                 |        | cribed with bin |
+| d      | off (0b00)        | None   | binary   | 11000 0b01: on            | 0b0             | None   | valid rules des |
+|        |                   |        |          | 11000 0b00: off           |                 |        | cribed with bin |
 |        |                   |        |          |                           |                 |        | ary masks       |
 +--------+-------------------+--------+----------+---------------------------+-----------------+--------+-----------------+
 | m1     | 2.3               | sec    | float    | None                      | None            | None   | a different par |
@@ -496,12 +496,12 @@ level 1, repr
 # CompositeDataset
 description= {'test CD'},
 meta= {
--------------  -------------------  ------------------
-a= 3.4         b= ever (2019-02-19  c= Invalid (Right)
+-------------  -----------------  ----------------
+a= 3.4         b= xy (2019-02-19  c= Invalid (IJK)
                01:02:03.456789
                1929229323456789)
 d= off (0b00)  m1= 2.3
--------------  -------------------  ------------------
+-------------  -----------------  ----------------
 MetaData-listeners = ListnerSet{}
 }
 
