@@ -1,6 +1,9 @@
 # -*- coding: utf-8 -*-
 
+import immutabledict
 import datetime
+import fractions
+import decimal
 import traceback
 from pprint import pprint
 import copy
@@ -8,6 +11,7 @@ import sys
 import functools
 import array
 from datetime import timezone
+import pytest
 
 from fdi.dataset.annotatable import Annotatable
 from fdi.dataset.copyable import Copyable
@@ -32,6 +36,8 @@ from fdi.dataset.finetime import FineTime, FineTime1
 from fdi.dataset.history import History
 from fdi.dataset.baseproduct import BaseProduct
 from fdi.dataset.product import Product
+from fdi.dataset.readonlydict import ReadOnlyDict
+from fdi.dataset.testproducts import SP
 from fdi.utils.checkjson import checkjson
 
 # import __builtins__
@@ -47,8 +53,8 @@ Classes.updateMapping()
 # make format output in /tmp/fditest_toString
 mko = 0
 
-if __name__ == '__main__' and __package__ == 'tests':
-    # run by python -m tests.test_dataset
+if __name__ == '__main__' and __package__ is None:
+    # run by python3 tests/test_dataset.py
 
     from outputs import nds20, nds30, nds2, nds3, out_GenericDataset, out_ArrayDataset, out_TableDataset, out_CompositeDataset
 else:
@@ -150,12 +156,27 @@ def test_serialization():
     # v = (1, 8.2, 'tt')
     # checkjson(v)
     # v = {(5, 4): 4, 'y': {('d', 60): 'ff', '%': '$'}}
-    # try:
+    # with testpy.raises(TypeError):
     #     checkjson(v)
-    # except Exception as e:
-    #     assert isinstance(e, TypeError)
-    # else:
-    #     assert False, 'Failed to raise exception'
+
+    # https://github.com/mverleg/pyjson_tricks
+    # json_tricks/test_class.py
+    class MyTestCls:
+        def __init__(self, **kwargs):
+            for k, v in kwargs.items():
+                setattr(self, k, v)
+
+    v = [
+        #arange(0, 10, 1, dtype=int).reshape((2, 5)),
+        datetime.datetime(year=2017, month=1, day=19,
+                          hour=23, minute=00, second=00),
+        1 + 2j,
+        decimal.Decimal(42),
+        fractions.Fraction(1, 3),
+        MyTestCls(s='ub', dct={'7': 7}),  # see later
+        set(range(7)),
+    ]
+    # checkjson(v)
 
 
 def test_sys():
@@ -484,12 +505,8 @@ def test_Parameter_init():
     assert v.valid is None
     # incompatible type
     a2 = DataWrapper()
-    try:
+    with pytest.raises(TypeError):
         v = Parameter(a2)
-    except Exception as e:
-        assert isinstance(e, TypeError)
-    else:
-        assert False, 'no exception caught'
     # also only one positional argument, but with a keyword arg
     a1 = 'a test parameter'
     a2 = FineTime1(8765)
@@ -618,12 +635,8 @@ def test_Parameter_features():
     a4 = 'float'
     if 0:  # strict
         # exception if value and type are  different
-        try:
+        with pytest.raises(TypeError):
             v = Parameter(a2, a1, a4)
-        except Exception as e:
-            assert isinstance(e, TypeError)
-        else:
-            assert False, 'no exception caught '+str(v.value)
     else:  # smart
         # not recommendedxs
         v = Parameter(a2, a1, a4)
@@ -634,33 +647,21 @@ def test_Parameter_features():
     a2 = 9.7
     a4 = 'hex'  # hex is internally int
     if 0:  # strict
-        try:
+        with pytest.raises(TypeError):
             v = Parameter(a2, a1, a4)
-        except Exception as e:
-            assert isinstance(e, TypeError)
-        else:
-            assert False, 'no exception caught '+str(v.value)
     else:  # smart
         v = Parameter(a2, a1, a4)
         assert v.value == 9
     # type not Number nor in DataTypes gets NotImplementedError
     a2 = 9
     a4 = 'guess'
-    try:
+    with pytest.raises(NotImplementedError):
         v = Parameter(a2, a1, a4)
-    except Exception as e:
-        assert isinstance(e, NotImplementedError)
-    else:
-        assert False, 'no exception caught'
     # value type not Number nor in DataTypes gets TypeError
     a2 = []
     a4 = 'integer'
-    try:
+    with pytest.raises(TypeError):
         v = Parameter(a2, a1, a4)
-    except Exception as e:
-        assert isinstance(e, TypeError)
-    else:
-        assert False, 'no exception caught'
 
     # NotImplemented
     # arbitrary argument order here
@@ -681,6 +682,7 @@ def test_Parameter_features():
     assert v.equals(v1)
     assert v == v1
     v1.value = -4
+
     assert not v.equals(v1),   deepcmp(v, v1, verbose=True)
     assert v != v1
     b2 = a2 + 0  # make a copy
@@ -691,7 +693,7 @@ def test_Parameter_features():
 
     # comparison with simplified syntax w/o '.value'
     x = 4
-    for t in [int, float, str, FineTime1]:
+    for t in [int, float, str, FineTime]:
         p = Parameter(value=t(x))
         assert p == t(x)
         assert p <= t(x)
@@ -854,7 +856,7 @@ def test_DateParameter():
     assert v.description == 'UNKNOWN'
     assert v.value == v.default
     assert v.type == 'finetime'
-    def0 = FineTime1(0)
+    def0 = FineTime(0)
     assert v.default == def0
     assert v.valid is None
     assert v.typecode == FineTime.DEFAULT_FORMAT
@@ -867,23 +869,19 @@ def test_DateParameter():
     v = DateParameter(description=a1, value=a2,
                       default=a5, valid=a6, typecode=a7)
     assert v.description == a1
-    assert v.value == FineTime1(a2)
+    assert v.value == FineTime(a2)
     assert v.type == 'finetime'
-    assert v.default == FineTime1(a5)
+    assert v.default == FineTime(a5)
     assert v.valid is None
     # if value and typecode are both given, typecode will be overwritten by value.format.
     assert v.typecode == v.value.format
 
     a8 = 9876
     v.value = a8
-    assert v.value == FineTime1(a8, format=v.typecode)
+    assert v.value == FineTime(a8, format=v.typecode)
 
-    try:
+    with pytest.raises(TypeError):
         DateParameter(3.3)
-    except TypeError as e:
-        pass
-    else:
-        assert False, 'fail to raise exception'
 
     checkjson(v)
 
@@ -949,7 +947,7 @@ def test_MetaData():
     # names of all parameters
     assert [n for n in v] == [a1, 'time', 'birthday']
 
-    checkjson(v)
+    checkjson(v, dbg=1)
 
     v.remove(a1)  # inherited from composite
     assert v.size() == 2
@@ -1301,23 +1299,12 @@ def test_TableModel():
 def test_TableDataset_init():
     # constructor
     # if data is not in a required form an exception is thrown
-    try:
+    with pytest.raises(TypeError):
         t = 5
         t = TableDataset(data=42)
-    except Exception as e:
-        assert issubclass(e.__class__, TypeError)
-    else:
-        assert False, 'no exception caught'
-    assert t == 5
 
-    try:
-        t = 51
+    with pytest.raises(DeprecationWarning):
         t = TableDataset(data=[{'name': 'a', 'column': Column(data=[])}])
-    except DeprecationWarning as e:
-        pass
-    else:
-        assert False, 'no warning caught'
-    assert t == 51
 
     # setData format 1: data is a  mapping. Needs pytnon 3.6 to guarantee order
     a1 = {'col1': Column(data=[1, 4.4, 5.4E3], unit='eV'),
@@ -1332,6 +1319,7 @@ def test_TableDataset_init():
     v2 = TableDataset()
     v2['col1'] = Column(data=[1, 4.4, 5.4E3], unit='eV')
     v2['col2'] = Column(data=[0, 43.2, 2E3], unit='cnt')
+
     assert v2 == v
 
     # 3: another syntax, list of tuples that does not need to use Column
@@ -1881,12 +1869,9 @@ def test_Indexed():
     assert v2.vLookUp((11, 31, 51)) == 1
     assert v2.vLookUp((11, 31, 51), return_index=False) == [
         1+n*10 for n in range(Nc)]
-    try:
+    with pytest.raises(KeyError):
         assert v2.vLookUp((1, 31, 51)) == [1+n*10 for n in range(Nc)]
-    except Exception as e:
-        assert isinstance(e, KeyError)
-    else:
-        assert False, 'Exception not caught'
+
     # multiple keys
     assert v2.vLookUp([(11, 31, 51), (14, 34, 54)], multiple=1) == [1, 4]
     assert v2.vLookUp([(11, 31, 51), (14, 34, 54)], return_index=False, multiple=True) == [
@@ -2134,12 +2119,8 @@ def check_Product(AProd):
     x.meta['an'] = Parameter('other')
     assert x.meta['an'].value == 'other'
     # cannot use x.an
-    try:
+    with pytest.raises(AttributeError):
         t = x.an
-    except Exception as e:
-        assert issubclass(e.__class__, AttributeError)
-    else:
-        assert False, 'no exception caught'
     # remove it
     x.meta.remove('an')
     # gone
@@ -2165,47 +2146,56 @@ def check_Product(AProd):
     checkgeneral(x)
 
 
+def test_ReadOnlyDict():
+    d = {3: 4, 5: {6: (7, 7)}, 'metadata': {
+        'version': {'data_type': 'string'}}}
+    v = ReadOnlyDict(d)
+    assert v[3] == 4
+    assert d['metadata']['version']['data_type'] == 'string'
+    assert id(v) != id(d)
+    assert id(v[5]) != id(d[5])
+    assert issubclass(v[5].__class__, ReadOnlyDict)
+    assert v[5][6] == (7, 7)
+    with pytest.raises(AttributeError):
+        v[3] = 2
+    with pytest.raises(AttributeError):
+        v[5] = 4
+    with pytest.raises(AttributeError):
+        v[5][6] = 4
+    # multiple
+    v2 = ReadOnlyDict(d)
+    assert id(v) != id(v2)
+    assert id(v[5]) != id(v2[5])
+    assert id(v[5][6]) == id(v2[5][6])  # value is not list or dict
+    assert id(v['metadata']['version']) != id(v2['metadata']['version'])
+    assert id(v['metadata']['version']['data_type']) == id(
+        v2['metadata']['version']['data_type'])  # value is not list or dict
+    with pytest.raises(AttributeError):
+        v[5][6] = [4.33]
+
+    # update
+    u = {}
+    u.update(v)
+    assert id(u[5]) != id(d[5])
+    assert id(u[5]) == id(v[5])
+    assert id(u['metadata']) != id(d['metadata'])
+    # update returns the same object
+    assert id(u['metadata']) == id(v['metadata'])
+
+    # copy generates a normal dict that does not point to orginsl dict-type counterparts
+    # cc = copy.deepcopy(v)
+    # assert cc == d
+    # assert issubclass(d[5].__class__, dict)
+    # assert id(v[3]) == id(cc[3])
+    # assert id(v[5]) != id(cc[5])
+    # assert id(v[5][6]) == id(cc[5][6])
+
+
 def test_Product():
     check_Product(Product)
 
 
 def test_SubProduct():
-    # sub-classing
-    # 'version' of subclass is int, not string
-    from fdi.dataset.product import ProductInfo as PPI
-
-    class SP(Product):
-        def __init__(self,
-                     description='UNKNOWN',
-                     typ_='SP',
-                     creator='UNKNOWN',
-                     version=9,
-                     creationDate=FineTime(0),
-                     rootCause='UNKNOWN',
-                     startDate=FineTime(0),
-                     endDate=FineTime(0),
-                     instrument='UNKNOWN',
-                     modelName='UNKNOWN',
-                     mission='_AGS',
-                     **kwds):
-            metasToBeInstalled = copy.copy(locals())
-            for x in ('self', '__class__', 'kwds'):
-                metasToBeInstalled.pop(x)
-            sp = {}
-            sp.update(PPI)
-            sp['name'] = self.__class__.__name__
-            sp['metadata']['version']['data_type'] = 'integer'
-            sp['metadata']['version']['default'] = 9
-            sp['metadata']['type']['default'] = sp['name']
-            self.zInfo = sp
-            super().__init__(metasToBeInstalled=metasToBeInstalled, **kwds)
-            super().installMetas(mtbi=metasToBeInstalled, prodInfo=self.zInfo)
-
-        @ property
-        def version(self): pass
-
-        @ version.setter
-        def version(self, p): pass
 
     y = SP()
 
@@ -2289,7 +2279,7 @@ def running(t):
     t()
 
 
-if __name__ == '__main__' and __package__ is not None:
+if __name__ == '__main__':
 
     if 0:
         from os import sys, path
